{% load static %}
<!DOCTYPE html>
<html lang="ko">
<head>
    <meta charset="utf-8">

    <meta http-equiv="X-UA-Compatible" content="IE=edge"/>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>

    <title>{{ site.name }}</title>

    {% block css %}
    {% endblock %}
</head>
<body class="st-container st-effect-3">

<div class="wrapper">

    {% block leader %}
        <div class="bg-dark d-none d-lg-block" style="height:150px; "></div>
        <div class="mb-5"></div>

        <section class="page-title bg-overlay-black-10 parallax mb-40" data-jarallax='{"speed": 0.6}'
                 style="background-image: url({% block bgimage %}'//placehold.it/1920x1000'{% endblock %});">
            <div class="container">
                <div class="row">
                    <div class="col-lg-12">
                        <div class="page-title-name">
                            <h1>{% block title %}Title{% endblock %}</h1>
                            <p>{% block subtitle %}Subtitle{% endblock %}</p>
                        </div>
                    </div>
                </div>
            </div>
        </section>
    {% endblock %}

    {% block popup %}
    {% endblock %}

    {% block content %}
    {% endblock %}
</div>
</body>
</html>
