# Generated by Django 2.1.7 on 2019-03-14 14:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('page', '0011_popup'),
    ]

    operations = [
        migrations.AlterField(
            model_name='popup',
            name='image',
            field=models.ImageField(blank=True, help_text='설정시 전체 팝업 내용은 이미지로만 채워집니다.', null=True, upload_to='popup', verbose_name='풀 이미지 팝업'),
        ),
        migrations.AlterField(
            model_name='popup',
            name='pos_y',
            field=models.CharField(default='150px', max_length=100, verbose_name='팝업 세로 위치'),
        ),
        migrations.AlterField(
            model_name='popup',
            name='title',
            field=models.CharField(help_text='관리자 구분용이고 외부에 표출되지 않습니다.', max_length=300, verbose_name='제목'),
        ),
    ]
