# Generated by Django 2.1.4 on 2018-12-09 12:17

from django.db import migrations, models
import easy_thumbnails.fields
import page.models


class Migration(migrations.Migration):

    dependencies = [
        ('page', '0007_auto_20181208_2123'),
    ]

    operations = [
        migrations.AlterField(
            model_name='slide',
            name='image',
            field=easy_thumbnails.fields.ThumbnailerImageField(help_text='슬라이드 이미지', upload_to=page.models.path_and_rename),
        ),
        migrations.AlterField(
            model_name='slide',
            name='subtitle',
            field=models.CharField(blank=True, default='', max_length=100, verbose_name='부제목'),
        ),
        migrations.AlterField(
            model_name='slide',
            name='title',
            field=models.CharField(blank=True, default='', max_length=40, verbose_name='제목'),
        ),
    ]
