{% extends "page/base.html" %}

{% block css %}
    <link rel="stylesheet" id="color-scheme" href="/static/css/page.css">
{% endblock %}

{% block content %}
    {% include style_name %}
{% endblock %}
