# Generated by Django 2.1.5 on 2019-01-20 16:57

import ckeditor_uploader.fields
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('page', '0009_post_featured'),
    ]

    operations = [
        migrations.AlterField(
            model_name='pagelet',
            name='content',
            field=ckeditor_uploader.fields.RichTextUploadingField(blank=True, default='', null=True, verbose_name='문구 내용'),
        ),
    ]
