# Generated by Django 2.1.4 on 2019-01-13 07:48

from django.db import migrations
import easy_thumbnails.fields


class Migration(migrations.Migration):

    dependencies = [
        ('page', '0008_auto_20181209_2117'),
    ]

    operations = [
        migrations.AddField(
            model_name='post',
            name='featured',
            field=easy_thumbnails.fields.ThumbnailerImageField(blank=True, help_text='이미지 추가 시 페이지 상단에 이미지 타이틀이 표시 됩니다.', null=True, upload_to='featured', verbose_name='타이틀 이미지'),
        ),
    ]
