# Generated by Django 2.0.5 on 2018-11-28 21:25

from django.db import migrations
import easy_thumbnails.fields


class Migration(migrations.Migration):

    dependencies = [
        ('page', '0003_postcategory_link'),
    ]

    operations = [
        migrations.AlterField(
            model_name='page',
            name='featured',
            field=easy_thumbnails.fields.ThumbnailerImageField(blank=True, null=True, upload_to='featured', verbose_name='타이틀 이미지'),
        ),
    ]
