# Generated by Django 2.0.5 on 2018-11-14 16:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('page', '0002_auto_20181114_0429'),
    ]

    operations = [
        migrations.AddField(
            model_name='postcategory',
            name='link',
            field=models.CharField(blank=True, max_length=1024, null=True, verbose_name='키테고리 페이지 링크'),
        ),
    ]
