# Generated by Django 2.0.5 on 2018-11-11 11:02

import ckeditor_uploader.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='DownloadableFile',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=40, verbose_name='표시 할 파일명')),
                ('file', models.FileField(upload_to='forms', verbose_name='양식 파일')),
                ('created', models.DateField(auto_now_add=True, verbose_name='생성일자')),
            ],
            options={
                'verbose_name': '다운로드용 파일',
                'verbose_name_plural': '다운로드용 파일 목록',
            },
        ),
        migrations.CreateModel(
            name='Page',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=40, verbose_name='페이지 제목')),
                ('subtitle', models.CharField(blank=True, max_length=100, null=True, verbose_name='페이지 부제목(선택)')),
                ('featured', models.ImageField(blank=True, null=True, upload_to='featured', verbose_name='타이틀 이미지')),
                ('theme', models.CharField(blank=True, choices=[('', '밝게'), ('dark', '어둡게'), ('gray', '회색조'), ('custom', '커스텀')], default='', max_length=10, verbose_name='컬러 테마')),
                ('code', models.SlugField(unique=True, verbose_name='페이지 코드')),
                ('content', ckeditor_uploader.fields.RichTextUploadingField(verbose_name='페이지 내용')),
                ('style', models.TextField(blank=True, default='', null=True, verbose_name='Style')),
                ('script', models.TextField(blank=True, default='', null=True, verbose_name='Script')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='업데이트')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='생성일')),
            ],
            options={
                'verbose_name': '페이지',
                'verbose_name_plural': '페이지 목록',
            },
        ),
        migrations.CreateModel(
            name='Pagelet',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=40, verbose_name='문구 제목')),
                ('code', models.SlugField(unique=True, verbose_name='문구 코드')),
                ('content', ckeditor_uploader.fields.RichTextUploadingField(verbose_name='문구 내용')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='업데이트')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='생성일')),
            ],
            options={
                'verbose_name': '반복사용문구',
                'verbose_name_plural': '반복사용문구 목록',
            },
        ),
        migrations.CreateModel(
            name='Post',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('topmost', models.BooleanField(default=False, help_text='선택 시 리스트 상단에 고정 됩니다.', verbose_name='상단고정')),
                ('active', models.BooleanField(default=True, help_text='체크 되어 있을 때 리스트에 표시 됩니다', verbose_name='표시여부')),
                ('title', models.CharField(max_length=40, verbose_name='포스트 제목')),
                ('content', ckeditor_uploader.fields.RichTextUploadingField(verbose_name='포스트 내용')),
                ('summery', models.TextField(verbose_name='요약 내용')),
                ('updated', models.DateTimeField(auto_now=True, verbose_name='업데이트')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='생성일')),
            ],
            options={
                'verbose_name': '포스트',
                'verbose_name_plural': '포스트 목록',
                'ordering': ['-topmost', '-created'],
            },
        ),
        migrations.CreateModel(
            name='PostCategory',
            fields=[
                ('code', models.CharField(max_length=10, primary_key=True, serialize=False, verbose_name='카테고리 코드')),
                ('name', models.CharField(max_length=40, verbose_name='카테고리 제목')),
                ('desc', models.CharField(max_length=80, verbose_name='카테고리 한줄 설명')),
                ('template', models.CharField(blank=True, default=None, help_text='이 카테고리가 특수한 템플릿을 쓸 경우 템플릿명', max_length=80, null=True, verbose_name='특수 템플릿')),
            ],
            options={
                'verbose_name': '포스트 카테고리',
                'verbose_name_plural': '포스트 카테고리 목록',
            },
        ),
        migrations.AddField(
            model_name='post',
            name='cate',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='page.PostCategory'),
        ),
    ]
